@@ -36,7 +36,8 @@ import java.util.Map;
 
 /**
  * <code>DirListingExportHandler</code> represents a simple export for collections:
- * a human-readable view listing the members.<br>
+ * a human-readable view listing the members.
+ * <p>
  * Note: If {@link #exportContent(ExportContext, boolean)} is called the view list
  * child nodes only, without respecting their representation as <code>DavResource</code>s.
  */
@@ -134,7 +135,6 @@ public class DirListingExportHandler implements IOHandler, PropertyHandler {
         // properties (content length undefined)
         context.setModificationTime(new Date().getTime());
         context.setContentType("text/html", "UTF-8");
-        context.setETag("");
 
         // data
         if (context.hasStream()) {
@@ -198,7 +198,6 @@ public class DirListingExportHandler implements IOHandler, PropertyHandler {
         // properties (content length undefined)
         context.setModificationTime(new Date().getTime());
         context.setContentType("text/html", "UTF-8");
-        context.setETag("");
 
         // data
         if (context.hasStream()) {
