@@ -16,6 +16,7 @@
  */
 package org.apache.jackrabbit.webdav.server;
 
+import org.apache.jackrabbit.webdav.ContentCodingAwareRequest;
 import org.apache.jackrabbit.webdav.DavCompliance;
 import org.apache.jackrabbit.webdav.DavConstants;
 import org.apache.jackrabbit.webdav.DavException;
@@ -63,6 +64,7 @@ import org.apache.jackrabbit.webdav.security.AclResource;
 import org.apache.jackrabbit.webdav.transaction.TransactionInfo;
 import org.apache.jackrabbit.webdav.transaction.TransactionResource;
 import org.apache.jackrabbit.webdav.util.CSRFUtil;
+import org.apache.jackrabbit.webdav.util.HttpDateTimeFormatter;
 import org.apache.jackrabbit.webdav.version.ActivityResource;
 import org.apache.jackrabbit.webdav.version.DeltaVConstants;
 import org.apache.jackrabbit.webdav.version.DeltaVResource;
@@ -76,9 +78,11 @@ import org.apache.jackrabbit.webdav.version.VersionResource;
 import org.apache.jackrabbit.webdav.version.VersionableResource;
 import org.apache.jackrabbit.webdav.version.report.Report;
 import org.apache.jackrabbit.webdav.version.report.ReportInfo;
+import org.apache.jackrabbit.webdav.xml.DomUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
+import org.w3c.dom.Element;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
@@ -87,10 +91,12 @@ import javax.servlet.http.HttpServletResponse;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.time.format.DateTimeParseException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.List;
+import java.util.Locale;
 
 /**
  * <code>AbstractWebdavServlet</code>
@@ -273,7 +279,10 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
         int methodCode = DavMethods.getMethodCode(request.getMethod());
         boolean noCache = DavMethods.isDeltaVMethod(webdavRequest) && !(DavMethods.DAV_VERSION_CONTROL == methodCode || DavMethods.DAV_REPORT == methodCode);
         WebdavResponse webdavResponse = new WebdavResponseImpl(response, noCache);
+
         try {
+            WebdavRequestContextHolder.setContext(new WebdavRequestContextImpl(webdavRequest));
+
             // make sure there is a authenticated user
             if (!getDavSessionProvider().attachSession(webdavRequest)) {
                 return;
@@ -287,13 +296,15 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
 
             // JCR-4165: reject any content-coding in request until we can
             // support it (see JCR-4166)
-            List<String> ces = getContentCodings(request);
-            if (!ces.isEmpty()) {
-                webdavResponse.setStatus(HttpServletResponse.SC_UNSUPPORTED_MEDIA_TYPE);
-                webdavResponse.setHeader("Accept-Encoding", "identity");
-                webdavResponse.setContentType("text/plain; charset=UTF-8");
-                webdavResponse.getWriter().println("Content-Encodings not supported, but received: " + ces);
-                webdavResponse.getWriter().flush();
+            if (!(webdavRequest instanceof ContentCodingAwareRequest)) {
+                List<String> ces = getContentCodings(request);
+                if (!ces.isEmpty()) {
+                    webdavResponse.setStatus(HttpServletResponse.SC_UNSUPPORTED_MEDIA_TYPE);
+                    webdavResponse.setHeader("Accept-Encoding", "identity");
+                    webdavResponse.setContentType("text/plain; charset=UTF-8");
+                    webdavResponse.getWriter().println("Content-Encodings not supported, but received: " + ces);
+                    webdavResponse.getWriter().flush();
+                }
             }
 
             // check matching if=header for lock-token relevant operations
@@ -305,18 +316,49 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
             if (!execute(webdavRequest, webdavResponse, methodCode, resource)) {
                 super.service(request, response);
             }
-
         } catch (DavException e) {
-            if (e.getErrorCode() == HttpServletResponse.SC_UNAUTHORIZED) {
-                sendUnauthorized(webdavRequest, webdavResponse, e);
+            handleDavException(webdavRequest, webdavResponse, e);
+        } catch (IOException ex) {
+            Throwable cause = ex.getCause();
+            if (cause instanceof DavException) {
+                handleDavException(webdavRequest, webdavResponse, (DavException) cause);
             } else {
-                webdavResponse.sendError(e);
+                throw ex;
             }
         } finally {
+            WebdavRequestContextHolder.clearContext();
             getDavSessionProvider().releaseSession(webdavRequest);
         }
     }
 
+    private void handleDavException(WebdavRequest webdavRequest, WebdavResponse webdavResponse, DavException ex)
+            throws IOException {
+        if (ex.getErrorCode() == HttpServletResponse.SC_UNAUTHORIZED) {
+            sendUnauthorized(webdavRequest, webdavResponse, ex);
+        } else {
+            Element condition = ex.getErrorCondition();
+            if (DomUtil.matches(condition, ContentCodingAwareRequest.PRECONDITION_SUPPORTED)) {
+                if (webdavRequest instanceof ContentCodingAwareRequest) {
+                    webdavResponse.setHeader("Accept-Encoding", ((ContentCodingAwareRequest) webdavRequest).getAcceptableCodings());
+                }
+            }
+            webdavResponse.sendError(ex);
+        }
+    }
+
+    /**
+     * If request payload was uncompressed, hint about acceptable content codings (RFC 7694)
+     */
+    private void addHintAboutPotentialRequestEncodings(WebdavRequest webdavRequest, WebdavResponse webdavResponse) {
+        if (webdavRequest instanceof ContentCodingAwareRequest) {
+            ContentCodingAwareRequest ccr = (ContentCodingAwareRequest)webdavRequest;
+            List<String> ces = ccr.getRequestContentCodings();
+            if (ces.isEmpty()) {
+                webdavResponse.setHeader("Accept-Encoding", ccr.getAcceptableCodings());
+            }
+        }
+    }
+
     /**
      * Sets the "WWW-Authenticate" header and writes the appropriate error
      * to the given webdav response.
@@ -531,7 +573,17 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
             return;
         }
 
-        long modSince = request.getDateHeader("If-Modified-Since");
+        long modSince = UNDEFINED_TIME;
+        try {
+            // will throw if multiple field lines present
+            String value = getSingletonField(request, "If-Modified-Since");
+            if (value != null) {
+                modSince = HttpDateTimeFormatter.parse(value);
+            }
+        } catch (IllegalArgumentException | DateTimeParseException ex) {
+            log.debug("illegal value for if-modified-since ignored: " + ex.getMessage());
+        }
+
         if (modSince > UNDEFINED_TIME) {
             long modTime = resource.getModificationTime();
             // test if resource has been modified. note that formatted modification
@@ -539,6 +591,12 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
             if (modTime != UNDEFINED_TIME && (modTime / 1000 * 1000) <= modSince) {
                 // resource has not been modified since the time indicated in the
                 // 'If-Modified-Since' header.
+
+                DavProperty<?> etagProp = resource.getProperty(DavPropertyName.GETETAG);
+                if (etagProp != null) {
+                    // 304 response MUST contain Etag when available
+                    response.setHeader("etag", etagProp.getValue().toString());
+                }
                 response.setStatus(HttpServletResponse.SC_NOT_MODIFIED);
                 return;
             }
@@ -572,7 +630,11 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
 
         MultiStatus mstatus = new MultiStatus();
         mstatus.addResourceProperties(resource, requestProperties, propfindType, depth);
-        response.sendMultiStatus(mstatus);
+
+        addHintAboutPotentialRequestEncodings(request, response);
+
+        response.sendMultiStatus(mstatus,
+                acceptsGzipEncoding(request) ? Collections.singletonList("gzip") : Collections.emptyList());
     }
 
     /**
@@ -596,6 +658,9 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
         MultiStatus ms = new MultiStatus();
         MultiStatusResponse msr = resource.alterProperties(changeList);
         ms.addResponse(msr);
+
+        addHintAboutPotentialRequestEncodings(request, response);
+
         response.sendMultiStatus(ms);
     }
 
@@ -625,6 +690,11 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
     protected void doPut(WebdavRequest request, WebdavResponse response,
                          DavResource resource) throws IOException, DavException {
 
+        if (request.getHeader("Content-Range") != null) {
+            response.sendError(DavServletResponse.SC_BAD_REQUEST, "Content-Range in PUT request not supported");
+            return;
+        }
+
         DavResource parentResource = resource.getCollection();
         if (parentResource == null || !parentResource.exists()) {
             // parent does not exist
@@ -1123,7 +1193,8 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
         }
 
         int statusCode = (report.isMultiStatusReport()) ? DavServletResponse.SC_MULTI_STATUS : DavServletResponse.SC_OK;
-        response.sendXmlResponse(report, statusCode);
+        addHintAboutPotentialRequestEncodings(request, response);
+        response.sendXmlResponse(report, statusCode, acceptsGzipEncoding(request) ? Collections.singletonList("gzip") : Collections.emptyList());
     }
 
     /**
@@ -1411,20 +1482,76 @@ abstract public class AbstractWebdavServlet extends HttpServlet implements DavCo
         return new OutputContextImpl(response, out);
     }
 
-    private List<String> getContentCodings(HttpServletRequest request) {
+    /**
+     * Obtain the (ordered!) list of content codings that have been used in the
+     * request
+     */
+    public static List<String> getContentCodings(HttpServletRequest request) {
+        return getListElementsFromHeaderField(request, "Content-Encoding");
+    }
+
+    /**
+     * Check whether recipient accepts GZIP content coding
+     */
+    private static boolean acceptsGzipEncoding(HttpServletRequest request) {
+        List<String> result = getListElementsFromHeaderField(request, "Accept-Encoding");
+        for (String s : result) {
+            s = s.replace(" ", "");
+            int semi = s.indexOf(';');
+            if ("gzip".equals(s)) {
+                return true;
+            } else if (semi > 0) {
+                String enc = s.substring(0, semi);
+                String parm = s.substring(semi + 1);
+                if ("gzip".equals(enc) && parm.startsWith("q=")) {
+                    float q = Float.valueOf(parm.substring(2));
+                    return q > 0;
+                }
+            }
+        }
+        return false;
+    }
+
+    private static List<String> getListElementsFromHeaderField(HttpServletRequest request, String fieldName) {
         List<String> result = Collections.emptyList();
-        for (@SuppressWarnings("unchecked")
-        Enumeration<String> ceh = request.getHeaders("Content-Encoding"); ceh.hasMoreElements();) {
+        for (Enumeration<String> ceh = request.getHeaders(fieldName); ceh.hasMoreElements();) {
             for (String h : ceh.nextElement().split(",")) {
                 if (!h.trim().isEmpty()) {
                     if (result.isEmpty()) {
                         result = new ArrayList<String>();
                     }
-                    result.add(h.trim());
+                    result.add(h.trim().toLowerCase(Locale.ENGLISH));
                 }
             }
         }
 
         return result;
     }
+
+    /**
+     * Get field value of a singleton field
+     * @param request HTTP request
+     * @param fieldName field name
+     * @return the field value (when there is indeed a single field line) or {@code null} when field not present
+     * @throws IllegalArgumentException when multiple field lines present
+     */
+    protected static String getSingletonField(HttpServletRequest request, String fieldName) {
+        Enumeration<String> lines = request.getHeaders(fieldName);
+        if (!lines.hasMoreElements()) {
+            return null;
+        } else {
+            String value = lines.nextElement();
+            if (!lines.hasMoreElements()) {
+                return value;
+            } else {
+                List<String> v = new ArrayList<>();
+                v.add(value);
+                while (lines.hasMoreElements()) {
+                    v.add(lines.nextElement());
+                }
+                throw new IllegalArgumentException("Multiple field lines for '" + fieldName + "' header field: " + v);
+            }
+        }
+    }
 }
+
